@@ -73,10 +73,11 @@ void meta_ui_unflicker_frame_bg (MetaUI *ui,
 void meta_ui_reset_frame_bg     (MetaUI *ui,
                                  Window  xwindow);
 
-void meta_ui_apply_frame_shape  (MetaUI *ui,
-                                 Window  xwindow,
-                                 int     new_window_width,
-                                 int     new_window_height);
+void meta_ui_apply_frame_shape  (MetaUI  *ui,
+                                 Window   xwindow,
+                                 int      new_window_width,
+                                 int      new_window_height,
+                                 gboolean window_has_shape);
 
 void meta_ui_queue_frame_draw (MetaUI *ui,
                                Window xwindow);
@@ -104,7 +105,9 @@ void            meta_ui_window_menu_popup (MetaWindowMenu     *menu,
 void            meta_ui_window_menu_free  (MetaWindowMenu     *menu);
 
 
-MetaImageWindow* meta_image_window_new          (int              max_width,
+MetaImageWindow* meta_image_window_new          (Display         *xdisplay,
+                                                 int              screen_number,
+                                                 int              max_width,
                                                  int              max_height);
 void             meta_image_window_free         (MetaImageWindow *iw);
 void             meta_image_window_set_showing  (MetaImageWindow *iw,
@@ -156,6 +159,8 @@ gboolean meta_ui_have_a_theme      (void);
 gboolean meta_ui_parse_accelerator (const char          *accel,
                                     unsigned int        *keysym,
                                     MetaVirtualModifier *mask);
+gboolean meta_ui_parse_modifier    (const char          *accel,
+                                    MetaVirtualModifier *mask);
 
 gboolean meta_ui_window_is_widget (MetaUI *ui,
                                    Window  xwindow);
